import type { ExactRecord, NonEmptyArray, PredIndexed } from "./_types";
/**
 * Splits a collection into sets, grouped by the result of running each value
 * through `fn`.
 *
 * @param items - The items to group.
 * @param fn - The grouping function. When `undefined` is returned the item
 * would be skipped and not grouped under any key.
 * @signature
 *    R.groupBy(array, fn)
 * @example
 *    R.groupBy([{a: 'cat'}, {a: 'dog'}] as const, R.prop('a')) // => {cat: [{a: 'cat'}], dog: [{a: 'dog'}]}
 *    R.groupBy([0, 1], x => x % 2 === 0 ? 'even' : undefined) // => {even: [0]}
 * @dataFirst
 * @indexed
 * @category Array
 */
export declare function groupBy<T, Key extends PropertyKey = PropertyKey>(items: ReadonlyArray<T>, fn: (item: T) => Key | undefined): ExactRecord<Key, NonEmptyArray<T>>;
/**
 * Splits a collection into sets, grouped by the result of running each value
 * through `fn`.
 *
 * @param fn - The grouping function. When `undefined` is returned the item
 * would be skipped and not grouped under any key.
 * @signature
 *    R.groupBy(fn)(array);
 * @example
 *    R.pipe(
 *      [{a: 'cat'}, {a: 'dog'}] as const,
 *      R.groupBy(R.prop('a'),
 *    ); // => {cat: [{a: 'cat'}], dog: [{a: 'dog'}]}
 *    R.pipe(
 *      [0, 1],
 *      R.groupBy(x => x % 2 === 0 ? 'even' : undefined),
 *    ); // => {even: [0]}
 * @dataLast
 * @indexed
 * @category Array
 */
export declare function groupBy<T, Key extends PropertyKey = PropertyKey>(fn: (item: T) => Key | undefined): (items: ReadonlyArray<T>) => ExactRecord<Key, NonEmptyArray<T>>;
export declare namespace groupBy {
    function indexed<T, Key extends PropertyKey = PropertyKey>(items: ReadonlyArray<T>, fn: PredIndexed<T, Key | undefined>): ExactRecord<Key, NonEmptyArray<T>>;
    function indexed<Value, Key extends PropertyKey = PropertyKey>(fn: PredIndexed<Value, Key | undefined>): (items: ReadonlyArray<Value>) => ExactRecord<Key, NonEmptyArray<Value>>;
}
//# sourceMappingURL=groupBy.d.ts.map